<?php
ini_set('session.cache_limiter','public');
session_cache_limiter(false);
session_start();
include("config.php");
?>
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<meta name="description" content="Real Estate PHP">
<meta name="keywords" content="">
<meta name="author" content="Unicoder">
<link rel="shortcut icon" href="images/favicon.png">
<link href="https://fonts.googleapis.com/css?family=Muli:400,400i,500,600,700&amp;display=swap" rel="stylesheet">
<link href="https://fonts.googleapis.com/css?family=Comfortaa:400,700" rel="stylesheet">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.1/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
<link rel="stylesheet" href="css/bootstrap.min.css">
<link rel="stylesheet" href="css/bootstrap-slider.css">
<link rel="stylesheet" href="css/jquery-ui.css">
<link rel="stylesheet" href="css/layerslider.css">
<link rel="stylesheet" href="css/color.css" id="color-change">
<link rel="stylesheet" href="css/owl.carousel.min.css">
<link rel="stylesheet" href="css/font-awesome.min.css">
<link rel="stylesheet" href="fonts/flaticon/flaticon.css">
<link rel="stylesheet" href="css/style.css">
<title>Clan Homes</title>
</head>
<body>
<div id="page-wrapper">
<div class="row">
<?php include("include/header.php"); ?>
<div class="full-row">
<div class="container">
<div class="row">
<div class="col-lg-8">
<div class="row">
<?php
$query=mysqli_query($con,"SELECT property.*, user.uname,user.utype,user.uimage FROM property,user WHERE property.uid=user.uid");
while($row=mysqli_fetch_array($query)){
?>
<div class="col-md-6">
<div class="featured-thumb hover-zoomer mb-4">
<div class="overlay-black overflow-hidden position-relative">
<img src="images/banner/banner.webp" alt="pimage">
<div class="sale bg-success text-white">Refrance : <?php echo $row[4]; ?></div>
<div class="price text-primary text-capitalize">
Rs : <?php echo $row[6]; ?>
<span class="text-white">Type : <?php echo $row[5]; ?></span>
</div>
</div>
<div class="featured-thumb-data shadow-one">
<div class="p-4">
<h5 class="text-secondary hover-text-success mb-2 text-capitalize">
<a href="propertydetail.php?pid=<?php echo $row[0]; ?>">
<?php echo $row[1]; ?>
</a>
</h5>
<span class="location text-capitalize">
<i class="fas fa-map-marker-alt text-success"></i>
<?php echo $row[8]; ?>
</span>
</div>
<div class="px-4 pb-4 d-inline-block w-100">
<div class="float-left text-capitalize">
<i class="fas fa-user text-success mr-1"></i>
<?php echo $row['uname']; ?>
</div>
<div class="float-right">
<i class="far fa-calendar-alt text-success mr-1"></i>
<?php echo date('d-m-Y',strtotime($row['date'])); ?>
</div>
</div>
</div>
</div>
</div>
<?php } ?>
</div>
</div>
<div class="col-lg-4">
<div class="sidebar-widget">
<h4 class="double-down-line-left text-secondary position-relative pb-4 my-4">Instalment Calculator</h4>
<form class="d-inline-block w-100" action="calc.php" method="post">
<div class="input-group mb-2">
<div class="input-group-prepend">
<div class="input-group-text">Rs</div>
</div>
<input type="text" class="form-control" name="amount" placeholder="Property Price">
</div>
<div class="input-group mb-2">
<div class="input-group-prepend">
<div class="input-group-text"><i class="far fa-calendar-alt"></i></div>
</div>
<input type="text" class="form-control" name="month" placeholder="Duration Year">
</div>
<div class="input-group mb-2">
<div class="input-group-prepend">
<div class="input-group-text">%</div>
</div>
<input type="text" class="form-control" name="interest" placeholder="Interest Rate">
</div>
<button type="submit" name="calc" class="btn btn-danger mt-4">Calculate Instalment</button>
</form>
</div>
</div>
</div>
</div>
</div>
<?php include("include/footer.php"); ?>
<a href="#" class="bg-secondary text-white hover-text-secondary" id="scroll">
<i class="fas fa-angle-up"></i>
</a>
</div>
</div>
<script src="js/jquery.min.js"></script>
<script src="js/greensock.js"></script>
<script src="js/layerslider.transitions.js"></script>
<script src="js/layerslider.kreaturamedia.jquery.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/owl.carousel.min.js"></script>
<script src="js/tmpl.js"></script>
<script src="js/jquery.dependClass-0.1.js"></script>
<script src="js/draggable-0.1.js"></script>
<script src="js/jquery.slider.js"></script>
<script src="js/wow.js"></script>
<script src="js/custom.js"></script>
</body>
</html>
